Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1221)

Unified Diff: chrome/browser/ui/passwords/passwords_client_ui_delegate.h

Issue 1776673003: Fix the password bubble titles for android. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix the tests Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/passwords/passwords_client_ui_delegate.h
diff --git a/chrome/browser/ui/passwords/passwords_client_ui_delegate.h b/chrome/browser/ui/passwords/passwords_client_ui_delegate.h
index cd9d7ef733fe6d17749093d2122670e5e4385530..5659fd352dc14607c354a99bbd250b9f2d0fb8b8 100644
--- a/chrome/browser/ui/passwords/passwords_client_ui_delegate.h
+++ b/chrome/browser/ui/passwords/passwords_client_ui_delegate.h
@@ -40,7 +40,8 @@ class PasswordsClientUIDelegate {
// Called when the site asks user to choose from credentials. This triggers
// the UI to prompt the user. |local_credentials| and |federated_credentials|
- // shouldn't both be empty.
+ // shouldn't both be empty. |origin| is a URL of the site that requested a
+ // credential.
// Returns true when the UI is shown. |callback| is called when the user made
// a decision. If the UI isn't shown the method returns false and doesn't call
// |callback|.
@@ -52,9 +53,10 @@ class PasswordsClientUIDelegate {
callback) = 0;
// Called when user is auto signed in to the site. |local_forms[0]| contains
// the credential returned to the site.
virtual void OnAutoSignin(
- ScopedVector<autofill::PasswordForm> local_forms) = 0;
+ ScopedVector<autofill::PasswordForm> local_forms,
+ const GURL& origin) = 0;
// Called when it's the right time to enable autosign-in explicitly.
virtual void OnPromptEnableAutoSignin() = 0;
@@ -52,9 +53,10 @@ class PasswordsClientUIDelegate {
callback) = 0;
// Called when user is auto signed in to the site. |local_forms[0]| contains
- // the credential returned to the site.
+ // the credential returned to the site. |origin| is a URL of the site.
virtual void OnAutoSignin(

Powered by Google App Engine
This is Rietveld 408576698